Package: VizModules
Title: Flexible, Interactive 'shiny' Modules for Almost Any Plot
Version: 0.4.0
Authors@R: 
    c(person(given = "Jared", family = "Andrews", email = "jared.andrews07@gmail.com", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-0780-6248")),
        person(given = "Jacob",
                family = "Martin",
                role = c("aut"),
                comment = c(ORCID = "0009-0007-6896-4796"),
                email = "jacob@martin-email.com"))
Description: Offers a core selection of interactivity-first 'shiny' modules for many 
    plot types meant to serve as flexible building blocks for applications and 
    as the base for more complex modules. These modules
    allow for the rapid and convenient construction of 'shiny' apps with very few lines
    of code and decouple plotting from the underlying data. These modules allow 
    for full plot aesthetic customization by the end user through UI inputs. Utility
    functions for simple UI organization, automated UI tooltips, and additional
    plot enhancements are also provided. Includes a multi-panel figure builder app
    for arranging multiple modules together in a free-form layout.
License: MIT + file LICENSE
Depends: shiny, dittoViz, plotly, R (>= 4.5), shinyBS, plotthis (>=
        0.13.0)
Imports: roclang, colourpicker, dplyr, DT, readxl, shinyjs, scales,
        shinyjqui, ggplot2, htmltools, jsonlite, methods, shinyWidgets
        (>= 0.7.0), htmlwidgets, zip
Encoding: UTF-8
LazyData: true
Suggests: drc, withr, ComplexHeatmap, InteractiveComplexHeatmap,
        circlize, grid, knitr, rmarkdown, testthat (>= 3.0.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
URL: https://j-andrews7.github.io/VizModules/,
        https://github.com/j-andrews7/VizModules
Config/roxygen2/version: 8.1.0
NeedsCompilation: no
Packaged: 2026-08-28 20:12:02 UTC; jandrews
Author: Jared Andrews [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-0780-6248>),
  Jacob Martin [aut] (ORCID: <https://orcid.org/0009-0007-6896-4796>)
Maintainer: Jared Andrews <jared.andrews07@gmail.com>
Repository: CRAN
Date/Publication: 2026-08-28 20:50:02 UTC
Built: R 4.6.0; ; 2026-08-28 21:48:23 UTC; unix
