# Generated by roxygen2: do not edit by hand

export(ComplexHeatmap_HeatmapApp)
export(ComplexHeatmap_HeatmapInfoOutputUI)
export(ComplexHeatmap_HeatmapInputsUI)
export(ComplexHeatmap_HeatmapMainOutputUI)
export(ComplexHeatmap_HeatmapOutputUI)
export(ComplexHeatmap_HeatmapServer)
export(ComplexHeatmap_HeatmapSubOutputUI)
export(add_ablines)
export(add_hlines)
export(add_plot_config)
export(add_reference_lines)
export(add_vlines)
export(adjust_column_values)
export(adjusted_axis_label)
export(apply_axis_title_to_annotations)
export(apply_facet_subplot_spacing)
export(apply_legend_styling)
export(apply_plotly_newshape)
export(apply_render_margins)
export(apply_stat_annotations)
export(apply_subplot_axis_styling)
export(apply_title_layout)
export(axis_titles_as_annotations)
export(build_facet_annotations)
export(build_facet_panel_borders)
export(build_model_row_spec)
export(clean_facet_dim)
export(collect_source_data)
export(compute_pairwise_stats)
export(createModuleApp)
export(create_axis_styles)
export(create_ggplot_axis_style)
export(create_source_download_handler)
export(create_stat_annotations)
export(dataFilterServer)
export(dataFilterUI)
export(default_palettes)
export(dittoViz_freqPlotApp)
export(dittoViz_freqPlotInputsUI)
export(dittoViz_freqPlotOutputUI)
export(dittoViz_freqPlotServer)
export(dittoViz_scatterPlotApp)
export(dittoViz_scatterPlotInputsUI)
export(dittoViz_scatterPlotOutputUI)
export(dittoViz_scatterPlotServer)
export(dittoViz_yPlotApp)
export(dittoViz_yPlotInputsUI)
export(dittoViz_yPlotOutputUI)
export(dittoViz_yPlotServer)
export(dumbbellPlot)
export(dumbbellPlotApp)
export(dumbbellPlotInputsUI)
export(dumbbellPlotOutputUI)
export(dumbbellPlotServer)
export(empty_plot)
export(figureBuilderApp)
export(figureBuilderServer)
export(figureBuilderUI)
export(finalize_manual_edits)
export(generate_pair_strings)
export(get_default)
export(get_documentation)
export(get_model_backend)
export(hide_input)
export(is_pure_type)
export(linePlot)
export(linePlotApp)
export(linePlotInputsUI)
export(linePlotOutputUI)
export(linePlotServer)
export(linetype_to_dash)
export(list_model_backends)
export(module_tack_ui)
export(multiColorPicker)
export(multiDynamicInput)
export(organize_inputs)
export(parallelCoordinatesPlot)
export(parallelCoordinatesPlotApp)
export(parallelCoordinatesPlotInputsUI)
export(parallelCoordinatesPlotOutputUI)
export(parallelCoordinatesPlotServer)
export(parse_numeric_list)
export(parse_pair_strings)
export(piePlot)
export(piePlotApp)
export(piePlotInputsUI)
export(piePlotOutputUI)
export(piePlotServer)
export(plotthis_AreaPlotApp)
export(plotthis_AreaPlotInputsUI)
export(plotthis_AreaPlotOutputUI)
export(plotthis_AreaPlotServer)
export(plotthis_BarPlotApp)
export(plotthis_BarPlotInputsUI)
export(plotthis_BarPlotOutputUI)
export(plotthis_BarPlotServer)
export(plotthis_BoxPlotApp)
export(plotthis_BoxPlotInputsUI)
export(plotthis_BoxPlotOutputUI)
export(plotthis_BoxPlotServer)
export(plotthis_DensityPlotApp)
export(plotthis_DensityPlotInputsUI)
export(plotthis_DensityPlotOutputUI)
export(plotthis_DensityPlotServer)
export(plotthis_DotPlotApp)
export(plotthis_DotPlotInputsUI)
export(plotthis_DotPlotOutputUI)
export(plotthis_DotPlotServer)
export(plotthis_HistogramApp)
export(plotthis_HistogramInputsUI)
export(plotthis_HistogramOutputUI)
export(plotthis_HistogramServer)
export(plotthis_SplitBarPlotApp)
export(plotthis_SplitBarPlotInputsUI)
export(plotthis_SplitBarPlotOutputUI)
export(plotthis_SplitBarPlotServer)
export(plotthis_ViolinPlotApp)
export(plotthis_ViolinPlotInputsUI)
export(plotthis_ViolinPlotOutputUI)
export(plotthis_ViolinPlotServer)
export(radarPlot)
export(radarPlotApp)
export(radarPlotInputsUI)
export(radarPlotOutputUI)
export(radarPlotServer)
export(recycle_line_style)
export(register_model_backend)
export(reset_annotation_inputs)
export(reset_axes_inputs)
export(reset_axis_title_text)
export(reset_legend_inputs)
export(reset_lines_inputs)
export(reset_plotly_inputs)
export(resolve_column_targets)
export(resolve_facet_layout)
export(resolve_facet_sharing)
export(resolve_palette)
export(safe_eval_filter)
export(safe_resolve_adj_fxn)
export(setup_auto_update_logic)
export(setup_axis_range)
export(setup_group_colors)
export(setup_manual_edits)
export(setup_reactive_defaults)
export(show_input)
export(stat_bracket_y_max)
export(string_to_linetypes)
export(toggle_input_cell)
export(uniform_annotation_inputs_ui)
export(uniform_axes_inputs_ui)
export(uniform_legend_inputs_ui)
export(uniform_lines_inputs_ui)
export(uniform_plotly_inputs_ui)
export(updateMultiColorPicker)
export(updateMultiDynamicInput)
export(update_viz_select)
export(use_vizmodules_skills)
export(validate_expression)
export(viz_select_input)
import(plotly)
import(shiny)
importFrom(colourpicker,
  colourInput,
  updateColourInput
)
importFrom(dittoViz,
  colLevels,
  dittoColors,
  freqPlot,
  scatterPlot,
  yPlot
)
importFrom(dplyr,
  across,
  all_of,
  group_by,
  mutate,
  summarise
)
importFrom(ggplot2,
  .data,
  aes,
  element_blank,
  element_line,
  element_rect,
  element_text,
  geom_boxplot,
  geom_text,
  ggplot,
  margin,
  sym,
  theme,
  theme_bw,
  theme_void,
  unit,
  waiver
)
importFrom(htmltools,
  attachDependencies,
  htmlDependency
)
importFrom(htmlwidgets,
  JS,
  onRender,
  saveWidget
)
importFrom(jsonlite,toJSON)
importFrom(methods,is)
importFrom(plotly,
  ggplotly,
  layout,
  plotly_build
)
importFrom(plotthis,
  AreaPlot,
  BarPlot,
  BoxPlot,
  DensityPlot,
  DotPlot,
  Histogram,
  SplitBarPlot,
  ViolinPlot
)
importFrom(readxl,read_excel)
importFrom(roclang,extract_roc_text)
importFrom(scales,
  brewer_pal,
  hue_pal,
  viridis_pal
)
importFrom(shiny,
  actionButton,
  br,
  checkboxInput,
  downloadButton,
  downloadHandler,
  icon,
  is.reactive,
  isolate,
  numericInput,
  observe,
  observeEvent,
  reactiveVal,
  reactiveValues,
  registerInputHandler,
  tagList,
  textAreaInput,
  textInput,
  updateCheckboxInput,
  updateNumericInput,
  updateTextAreaInput,
  updateTextInput
)
importFrom(shinyBS,tipify)
importFrom(shinyWidgets,
  materialSwitch,
  updateMaterialSwitch
)
importFrom(shinyjqui,jqui_resizable)
importFrom(shinyjs,
  click,
  delay,
  hide,
  runjs,
  show,
  useShinyjs
)
importFrom(stats,
  aggregate,
  aov,
  approx,
  as.formula,
  coef,
  kruskal.test,
  lm,
  loess,
  median,
  na.omit,
  p.adjust,
  predict,
  reformulate,
  setNames,
  t.test,
  wilcox.test
)
importFrom(tools,
  file_ext,
  file_path_sans_ext
)
importFrom(utils,
  combn,
  modifyList,
  read.csv,
  read.delim,
  write.csv
)
importFrom(zip,zip)
